@ECHO OFF

ECHO CityInfo(R) OSM data import command set

IF "%1"=="" GOTO :help
IF "%2"=="" GOTO :help

SET SOURCE_FILE=%1
IF NOT EXIST %1 (ECHO "Source file %1 not found" & GOTO :help)

SET OSM_CONFIG_PATH=config\%2
dir %OSM_CONFIG_PATH% >nul 2>nul
IF %ERRORLEVEL% GTR 0 (ECHO Configuration folder %OSM_CONFIG_PATH% not found & GOTO :help)

SET OUTPUT_PATH=..

FOR /F %%v in ('@type %OSM_CONFIG_PATH%\clipbounds.txt') do @SET CLIP_BOUNDS=%%v
SET UTILS_PATH=..\utils

SET OSM_CONFIG_MAIN="%OSM_CONFIG_PATH%\citymain.xml"
SET OSM_CONFIG_INDEX="%OSM_CONFIG_PATH%\cityindex.xml"
SET CITY_CLASSIFIER="%OSM_CONFIG_PATH%\city.clf"

SET OSM_DOM_FILE="%TEMP%\~cityinfo.oso"
SET TEMP_DATA_FILE="%TEMP%\~cityinfo.tmp"
SET MAIN_MAP_CONFIG=%OSM_CONFIG_PATH%\citymain.cfg
SET INDEX_MAP_CONFIG=%OSM_CONFIG_PATH%\cityindex.cfg

ECHO Importing %SOURCE_FILE% using %2 configuration

REM Tool definitions
SET OSM2BIN="%UTILS_PATH%\osm2bin.exe"
SET OSMBIN2MAP="%UTILS_PATH%\osmbin2map.exe"
SET OSM_CITY_POSTPROCESS="%UTILS_PATH%\osmcitypostprocess.exe"
SET CITY_MAP_CONVERTER="%UTILS_PATH%\cityconverter.exe"

ECHO Processing OSM DOM
%OSM2BIN% /q %SOURCE_FILE% %OSM_DOM_FILE%

ECHO Main map processing
%OSMBIN2MAP% %OSM_DOM_FILE% %TEMP_DATA_FILE% /q -bounds:%CLIP_BOUNDS% -o:cmf -nodefault -c:%OSM_CONFIG_MAIN% -lockmappers
%OSM_CITY_POSTPROCESS% %TEMP_DATA_FILE% /q -m:"%OSM_CONFIG_PATH%"
%CITY_MAP_CONVERTER% /q %TEMP_DATA_FILE% -o:"%OUTPUT_PATH%\city.act" -t:citymain -tolerance:0.5 -custom_config:%MAIN_MAP_CONFIG% -c:%CITY_CLASSIFIER% -cv:none
DEL %TEMP_DATA_FILE%

ECHO Index map processing
%OSMBIN2MAP% /q %OSM_DOM_FILE% %TEMP_DATA_FILE% -bounds:%CLIP_BOUNDS% -o:cmf -nodefault -c:%OSM_CONFIG_INDEX% -lockmappers
%CITY_MAP_CONVERTER% /q %TEMP_DATA_FILE% -o:"%OUTPUT_PATH%\city.anv" -tolerance:5 -custom_config:%INDEX_MAP_CONFIG% -cv:none
DEL %TEMP_DATA_FILE%

DEL %OSM_DOM_FILE%

COPY /y %CITY_CLASSIFIER% %OUTPUT_PATH%
ECHO Finished
GOTO exit

:help
ECHO USAGE: import.bat ^<source filename^> ^<config name^>

:exit
